"use strict";

/**
 * The MIT License (MIT)
 * Copyright (c) 2017-present Dmitry Soshnikov <dmitry.soshnikov@gmail.com>
 */
var parser = require('../../parser');

var generator = require('..');

function test(re) {
  var reStr = re.toString();
  var parsed = parser.parse(reStr);
  var generated = generator.generate(parsed);
  expect(generated).toBe(reStr);
}

describe('generator-basic', function () {
  it('simple char', function () {
    test(/a/);
  });
  it('space char', function () {
    test(/ /);
  });
  it('escaped char', function () {
    test(/\z/);
  });
  it('unicode char', function () {
    test(/\u0036/);
  });
  it('hex char', function () {
    test(/\x3B/);
  });
  it('octal char', function () {
    test(/\073/);
  });
  it('meta char', function () {
    test(/\n/);
    test(/\r/);
    test(/\s/);
    test(/\S/);
    test(/\d/);
    test(/\D/);
    test(/\w/);
    test(/\W/);
    test(/\v/);
    test(/\f/);
  });
  it('alternative', function () {
    test(/abc/);
  });
  it('disjunction', function () {
    test(/a|b/);
  });
  it('disjunction - empty left', function () {
    test(/|a/);
  });
  it('disjunction - empty right', function () {
    test(/a|/);
  });
  it('capturing group', function () {
    test(/(ab)/);
  });
  it('empty capturing group', function () {
    test(/()/);
  });
  it('non-capturing group', function () {
    test(/(?:ab)/);
  });
  it('named group', function () {
    test("/(?<foo\\u003B\\u{003B}>bar)/u");
  });
  it('empty named group', function () {
    test("/(?<foo\\u003B\\u{003B}>)/u");
  });
  it('empty non-capturing group', function () {
    test(/(?:)/);
  });
  it('numeric backreference', function () {
    test(/(a)\1/);
  });
  it('named backreference', function () {
    test("/(?<foo\\u003B\\u{003B}>)\\k<foo\\u003B\\u{003B}>/u");
  });
  it('basic-assertion', function () {
    test(/^/);
    test(/$/);
    test(/\b/);
    test(/\B/);
  });
  it('positive character class', function () {
    test(/[a-z0]/);
  });
  it('empty positive character class', function () {
    /*eslint no-empty-character-class:0*/
    test(/[]/);
  });
  it('negative character class', function () {
    test(/[^a-z0]/);
  });
  it('empty negative character class', function () {
    test(/[^]/);
  });
  it('positive lookahead assertion', function () {
    test(/(?=abc)/);
  });
  it('empty positive lookahead assertion', function () {
    test(/(?=)/);
  });
  it('negative lookahead assertion', function () {
    test(/(?!abc)/);
  });
  it('empty negative lookahead assertion', function () {
    test(/(?!)/);
  });
  it('positive lookbehind assertion', function () {
    test('/(?<=abc)/');
  });
  it('empty positive lookbehind assertion', function () {
    test('/(?<=)/');
  });
  it('negative lookbehind assertion', function () {
    test('/(?<!abc)/');
  });
  it('empty negative lookbehind assertion', function () {
    test('/(?<!)/');
  });
  it('simple greedy quantifier', function () {
    test(/a?/);
    test(/a*/);
    test(/a+/);
  });
  it('simple non-greedy quantifier', function () {
    test(/a??/);
    test(/a*?/);
    test(/a+?/);
  });
  it('range greedy quantifier', function () {
    test(/a{1}/);
    test(/a{1,}/);
    test(/a{1,3}/);
  });
  it('range non-greedy quantifier', function () {
    test(/a{1}?/);
    test(/a{1,}?/);
    test(/a{1,3}?/);
  });
});