/**
 * The MIT License (MIT)
 * Copyright (c) 2017-present Dmitry Soshnikov <dmitry.soshnikov@gmail.com>
 */
'use strict';

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

var State = require('../state');

function setIndex(set, index) {
  return _toConsumableArray(set)[index];
}

describe('fa-state', function () {
  it('accepting', function () {
    var A = new State({
      accepting: true
    });
    var B = new State();
    B.accepting = true;
    var C = new State();
    expect(A.accepting).toBe(true);
    expect(B.accepting).toBe(true);
    expect(C.accepting).toBe(false);
  });
  it('add symbol transitions', function () {
    var A = new State();
    var B = new State();
    expect(A.getTransitions().size).toBe(0);
    expect(B.getTransitions().size).toBe(0);
    A.addTransition('b', B);
    expect(A.getTransitions().size).toBe(1);
    expect(B.getTransitions().size).toBe(0);
    expect(A.getTransitionsOnSymbol('b').size).toBe(1);
    expect(setIndex(A.getTransitionsOnSymbol('b'), 0)).toBe(B);
    var C = new State();
    A.addTransition('b', C);
    expect(A.getTransitions().size).toBe(1);
    expect(A.getTransitionsOnSymbol('b').size).toBe(2);
    expect(setIndex(A.getTransitionsOnSymbol('b'), 1)).toBe(C);
  });
});