/**
 * The MIT License (MIT)
 * Copyright (c) 2017-present Dmitry Soshnikov <dmitry.soshnikov@gmail.com>
 */
'use strict';

var DFAMinimizer = require('../dfa-minimizer');

var fa = require('../../index');

function testMinimization(_ref) {
  var regexp = _ref.regexp,
      originalTable = _ref.originalTable,
      minimizedTable = _ref.minimizedTable,
      newAcceptingStates = _ref.newAcceptingStates;
  var dfa = fa.toDFA(regexp);
  expect(dfa.getTransitionTable()).toEqual(originalTable);
  var minimized = DFAMinimizer.minimize(dfa);
  expect(minimized.getTransitionTable()).toEqual(minimizedTable);
  expect(minimized.getAcceptingStateNumbers()).toEqual(newAcceptingStates);
}

describe('dfa-minimizer', function () {
  it('a|b', function () {
    testMinimization({
      regexp: /a|b|c|d/,
      originalTable: {
        1: {
          a: 5,
          b: 4,
          c: 3,
          d: 2
        },
        2: {},
        3: {},
        4: {},
        5: {}
      },
      minimizedTable: {
        1: {
          a: 2,
          b: 2,
          c: 2,
          d: 2
        },
        2: {}
      },
      newAcceptingStates: new Set([2])
    });
  });
  it('a*', function () {
    testMinimization({
      regexp: /a*/,
      originalTable: {
        1: {
          a: 2
        },
        2: {
          a: 2
        }
      },
      minimizedTable: {
        1: {
          a: 1
        }
      },
      newAcceptingStates: new Set([1])
    });
  });
  it('aa*', function () {
    testMinimization({
      regexp: /aa*/,
      originalTable: {
        1: {
          a: 2
        },
        2: {
          a: 3
        },
        3: {
          a: 3
        }
      },
      minimizedTable: {
        1: {
          a: 2
        },
        2: {
          a: 2
        }
      },
      newAcceptingStates: new Set([2])
    });
  });
  it('ab', function () {
    testMinimization({
      regexp: /ab/,
      originalTable: {
        1: {
          a: 3
        },
        2: {},
        3: {
          b: 2
        }
      },
      // Stays the same, already minimal.
      minimizedTable: {
        1: {
          a: 3
        },
        2: {},
        3: {
          b: 2
        }
      },
      newAcceptingStates: new Set([2])
    });
  });
});