/**
 * The MIT License (MIT)
 * Copyright (c) 2017-present Dmitry Soshnikov <dmitry.soshnikov@gmail.com>
 */
'use strict';

var _require = require('../../../transform'),
    transform = _require.transform;

var charClassToMeta = require('../char-class-to-meta-transform');

describe('char-class-to-meta', function () {
  it('replaces number ranges', function () {
    var re = transform(/[0-9$]/, [charClassToMeta]);
    expect(re.toString()).toBe('/[\\d$]/');
  });
  it('replaces word ranges', function () {
    var re = transform(/[0-9a-zA-Z_$]/, [charClassToMeta]);
    expect(re.toString()).toBe('/[\\w$]/');
  });
  it('replaces word ranges when regexp has i flag', function () {
    var re = transform(/[0-9a-z_$]/i, [charClassToMeta]);
    expect(re.toString()).toBe('/[\\w$]/i');
  });
  it('replaces word ranges when regexp has i and u flags', function () {
    var re = transform("/[\\da-zA-Z_\\u017F\\u212A$]/iu", [charClassToMeta]);
    expect(re.toString()).toBe('/[\\w$]/iu');
  });
  it('whitespace ranges', function () {
    var re = transform(/[ \f\n\r\t\v\u00a0\u1680\u2000-\u200a\u2028\u2029\u202f\u205f\u3000\ufeff]/, [charClassToMeta]);
    expect(re.toString()).toBe('/[\\s]/');
  });
  it('whitespace ranges order do not matters', function () {
    var re = transform(/[\f \n\r\t\v\u00a0\u1680\u2000-\u200a\u2028\u2029\u202f\u205f\u3000\ufeff]/, [charClassToMeta]);
    expect(re.toString()).toBe('/[\\s]/');
  });
  it('whitespace ranges duplicated chars', function () {
    var re = transform(/[ \f\n\n\r\t\v\u00a0\u1680\u2000-\u200a\u2028\u2029\u202f\u205f\u3000\ufeff]/, [charClassToMeta]);
    expect(re.toString()).toBe('/[\\s]/');
  });
  it('whitespace ranges missing chars', function () {
    var re = transform(/[ \n\r\t\v\u00a0\u1680\u2000-\u200a\u2028\u2029\u202f\u205f\u3000\ufeff]/, [charClassToMeta]);
    expect(re.toString()).toBe("/[ \\n\\r\\t\\v\\u00a0\\u1680\\u2000-\\u200a\\u2028\\u2029\\u202f\\u205f\\u3000\\ufeff]/");
  });
});