/**
 * The MIT License (MIT)
 * Copyright (c) 2017-present Dmitry Soshnikov <dmitry.soshnikov@gmail.com>
 */
'use strict';

var _require = require('../../../transform'),
    transform = _require.transform;

var disjunctionRemoveDuplicates = require('../disjunction-remove-duplicates-transform');

describe('(ab|bc|ab) -> (ab|bc)', function () {
  it('removes duplicates from disjunction', function () {
    var re = transform(/ab|bc|ab/, [disjunctionRemoveDuplicates]);
    expect(re.toString()).toBe('/ab|bc/');
  });
  it('preserves order', function () {
    var re = transform(/bc|bc|ab/, [disjunctionRemoveDuplicates]);
    expect(re.toString()).toBe('/bc|ab/');
  });
  it('replaces disjunction containing only one part', function () {
    var re = transform(/ab|ab/, [disjunctionRemoveDuplicates]);
    expect(re.toString()).toBe('/ab/');
  });
  it('does not merge capturing groups', function () {
    var re = transform(/(ab)|(ab)/, [disjunctionRemoveDuplicates]);
    expect(re.toString()).toBe('/(ab)|(ab)/');
  });
  it('handles recursion', function () {
    var re = transform(/(ab|bc|ab)|(bc|cd|bc)/, [disjunctionRemoveDuplicates]);
    expect(re.toString()).toBe('/(ab|bc)|(bc|cd)/');
    var re2 = transform(/(?:ab|bc|ab)|(?:ab|bc|ab)/, [disjunctionRemoveDuplicates]);
    expect(re2.toString()).toBe('/(?:ab|bc)/');
  });
  it('handles empty parts', function () {
    var re = transform(/a|b|||/, [disjunctionRemoveDuplicates]);
    expect(re.toString()).toBe('/a|b|/');
  });
});