/**
 * The MIT License (MIT)
 * Copyright (c) 2017-present Dmitry Soshnikov <dmitry.soshnikov@gmail.com>
 */
'use strict';

var _require = require('../../../transform'),
    transform = _require.transform;

var singleCharsGroupToCharClass = require('../group-single-chars-to-char-class');

describe('(a|b|c) -> ([abc])', function () {
  it('replaces single chars disjunction to char class', function () {
    var re = transform(/a|b|c/, [singleCharsGroupToCharClass]);
    expect(re.toString()).toBe('/[abc]/');
  });
  it('merges single chars disjunction with character class', function () {
    var re = transform(/[43]|a|b|[53]|c|[9]/, [singleCharsGroupToCharClass]);
    expect(re.toString()).toBe('/[3459abc]/');
  });
  it('replaces single chars group to char class', function () {
    var re = transform(/(a|b|c)/, [singleCharsGroupToCharClass]);
    expect(re.toString()).toBe('/([abc])/');
  });
  it('works with metachars too', function () {
    var re = transform(/(\d|\n)/, [singleCharsGroupToCharClass]);
    expect(re.toString()).toBe(/([\d\n])/.toString());
  });
  it('merges duplicates in group', function () {
    var re = transform(/(a|b|a|b)/, [singleCharsGroupToCharClass]);
    expect(re.toString()).toBe('/([ab])/');
  });
  it('removes non-capturing group', function () {
    var re = transform(/(?:a|b|c)/, [singleCharsGroupToCharClass]);
    expect(re.toString()).toBe('/[abc]/');
  });
  it('have no effect on multichar values', function () {
    var re = transform(/(a|b|no)/, [singleCharsGroupToCharClass]);
    expect(re.toString()).toBe('/(a|b|no)/');
  });
  it('has no effet on empty values', function () {
    var re = transform(/(a|b|)/, [singleCharsGroupToCharClass]);
    expect(re.toString()).toBe('/(a|b|)/');
  });
  it('does not merge in negative class', function () {
    var re = transform(/(_|[^\s\w])/g, [singleCharsGroupToCharClass]);
    expect(re.toString()).toBe('/(_|[^\\s\\w])/g');
  });
});