"use strict";

/**
 * The MIT License (MIT)
 * Copyright (c) 2017-present Dmitry Soshnikov <dmitry.soshnikov@gmail.com>
 */
var parser = require('../../parser');

var _require = require('..'),
    TransformResult = _require.TransformResult,
    transform = _require.transform;

var defaultRe = /a{1,}/i;
var defaultReString = "".concat(defaultRe);
var defaultAst = parser.parse(defaultReString, {
  captureLocations: true
});
describe('transform-basic', function () {
  function test(re) {
    var result = transform(re, {
      Quantifier: function Quantifier(path) {
        var node = path.node;

        if (node.kind === 'Range' && node.from == 1 && !node.to) {
          path.replace({
            type: 'Quantifier',
            kind: '+',
            greedy: node.greedy
          });
        }
      }
    });
    expect(result).toBeInstanceOf(TransformResult);
    expect(result.toString()).toBe('/a+/i');
    expect(result.toRegExp()).toEqual(/a+/i);
    expect(result.getSource()).toBe('a+');
    expect(result.getFlags()).toBe('i');
    expect(result.getAST()).toEqual({
      type: 'RegExp',
      body: {
        type: 'Repetition',
        expression: {
          type: 'Char',
          value: 'a',
          symbol: 'a',
          kind: 'simple',
          codePoint: 'a'.codePointAt(0),
          loc: {
            source: 'a',
            start: {
              line: 1,
              column: 1,
              offset: 1
            },
            end: {
              line: 1,
              column: 2,
              offset: 2
            }
          }
        },
        quantifier: {
          type: 'Quantifier',
          kind: '+',
          greedy: true
        },
        loc: {
          source: 'a{1,}',
          // NOTE: original source might not be updated
          start: {
            line: 1,
            column: 1,
            offset: 1
          },
          end: {
            line: 1,
            column: 6,
            offset: 6
          }
        }
      },
      flags: 'i',
      loc: {
        source: '/a{1,}/i',
        start: {
          line: 1,
          column: 0,
          offset: 0
        },
        end: {
          line: 1,
          column: 8,
          offset: 8
        }
      }
    });
  }

  it('from string', function () {
    test(defaultReString);
  });
  it('from regexp', function () {
    test(defaultRe);
  });
  it('from ast', function () {
    test(defaultAst);
  });
});