"use strict";

/**
 * The MIT License (MIT)
 * Copyright (c) 2017-present Dmitry Soshnikov <dmitry.soshnikov@gmail.com>
 */
var parser = require('../../parser');

var transformUtils = require('../utils');

describe('transform-utils', function () {
  it('disjunctionToList', function () {
    var disjunction = parser.parse('/a|b|c|d/').body;
    var list = transformUtils.disjunctionToList(disjunction);
    expect(list).toEqual([disjunction.left.left.left, // a
    disjunction.left.left.right, // b
    disjunction.left.right, // c
    disjunction.right]);
  });
  it('handles empty parts', function () {
    var disjunction = parser.parse('/|/').body;
    var list = transformUtils.disjunctionToList(disjunction);
    expect(list).toEqual([disjunction.left, // null
    disjunction.right // null
    ]);
  });
  it('disjunctionToList', function () {
    var list = [{
      type: 'Char',
      value: 'a',
      kind: 'simple',
      codePoint: 97,
      symbol: 'a'
    }, {
      type: 'Char',
      value: 'b',
      kind: 'simple',
      codePoint: 98,
      symbol: 'b'
    }, {
      type: 'Char',
      value: 'c',
      kind: 'simple',
      codePoint: 99,
      symbol: 'c'
    }, {
      type: 'Char',
      value: 'd',
      kind: 'simple',
      codePoint: 100,
      symbol: 'd'
    }];
    var disjunction = transformUtils.listToDisjunction(list);
    var expected = parser.parse('/a|b|c|d/').body;
    expect(disjunction).toEqual(expected);
  });
  it('increaseQuantifierByOne', function () {
    var quantifiers = [{
      type: 'Quantifier',
      kind: '*',
      greedy: true
    }, {
      type: 'Quantifier',
      kind: '+',
      greedy: false
    }, {
      type: 'Quantifier',
      kind: '?',
      greedy: true
    }, {
      type: 'Quantifier',
      kind: 'Range',
      from: 2,
      to: 2,
      greedy: true
    }, {
      type: 'Quantifier',
      kind: 'Range',
      from: 2,
      greedy: false
    }, {
      type: 'Quantifier',
      kind: 'Range',
      from: 2,
      to: 3,
      greedy: true
    }];
    var quantifiersIncreased = [{
      type: 'Quantifier',
      kind: '+',
      greedy: true
    }, {
      type: 'Quantifier',
      kind: 'Range',
      from: 2,
      greedy: false
    }, {
      type: 'Quantifier',
      kind: 'Range',
      from: 1,
      to: 2,
      greedy: true
    }, {
      type: 'Quantifier',
      kind: 'Range',
      from: 3,
      to: 3,
      greedy: true
    }, {
      type: 'Quantifier',
      kind: 'Range',
      from: 3,
      greedy: false
    }, {
      type: 'Quantifier',
      kind: 'Range',
      from: 3,
      to: 4,
      greedy: true
    }];
    quantifiers.forEach(function (quantifier, i) {
      transformUtils.increaseQuantifierByOne(quantifier);
      expect(quantifier).toEqual(quantifiersIncreased[i]);
    });
  });
});